@@ -59,28 +59,6 @@ def parse_args():
     return parser.parse_args()
 
 
-def try_find_compatible_libs(repo: LibRepo, name: str, ver: str, platform: str, arch=None, build=None):
-    libs = []
-    if not arch and not build:
-        for b in available_build_names():
-            for p in available_arches(platform):
-                lib = LibData(name=name, version=ver, platform=platform, arch=p, build=b)
-                if repo.exist(lib):
-                    libs.append(lib)
-    if arch and not build:
-        for b in available_build_names():
-            lib = LibData(name=name, version=ver, platform=platform, arch=arch, build=b)
-            if repo.exist(lib):
-                libs.append(lib)
-    if not arch and build:
-        for p in available_arches(platform):
-            lib = LibData(name=name, version=ver, platform=platform, arch=p, build=build)
-            if repo.exist(lib):
-                libs.append(lib)
-
-    return libs
-
-
 def list_command(args):
     print(str(LibRepo().pull_repo()))
 
@@ -116,7 +94,7 @@ def lib_get():
             libs.append(lib)
             continue
 
-        compatible_libs = try_find_compatible_libs(repo, name, ver, platform, arch, build)
+        compatible_libs = repo.find_compatible_libs(name, ver, platform, arch, build)
         if compatible_libs:
             libs.extend(compatible_libs)
         else:
